@@ -100,7 +100,7 @@ class Algo(object):
 	return(ret)
 
 def today():
-    t=time.time() + time.timezone
+    t=time.time() - time.timezone
     day=int(t/86400)
 
     return(day)
